import flask
import nbserve
import os


flask_app = flask.Flask(nbserve.__progname__)

flask_app.config['DEBUG'] = True

from IPython.html.services.notebooks.filenbmanager import FileNotebookManager


nbmanager = FileNotebookManager(notebook_dir='.')

def set_working_directory(path):
    if not os.path.exists(path):
        raise IOError('Path not found: %s' % os.path.abspath(path))
    nbmanager.notebook_dir = path

@flask_app.route('/')
def render_index():
    template = """<html>
    <body>
    <h2>Notebooks</h2>
    <ul>
        {% for notebook in notebooks %}
            <li><a href='{{ notebook.name }}'>{{notebook.name}}</a></li>
        {% endfor %}
    </ul>
    </body>
    </html>"""
    return flask.render_template_string(template, notebooks=nbmanager.list_notebooks('.'))

@flask_app.route('/<nbname>/')
def render_page(nbname):
    from runipy.notebook_runner import NotebookRunner
    from IPython.nbconvert.exporters.html import HTMLExporter

    if not nbmanager.notebook_exists(nbname):
        print "Notebook %s does not exist." % nbname
        flask.abort(404)

    print "Loading notebook %s" % nbname
    nbmanager.trust_notebook(nbname)
    nb = nbmanager.get_notebook(nbname)
    print "Making runner..."
    runner = NotebookRunner(nb['content'])
    print "Running notebook"
    runner.run_notebook()
    print "Exporting notebook"
    exporter = HTMLExporter(
        #config=Config({'HTMLExporter':{'default_template':args.template}})
    )
    output, resources = exporter.from_notebook_node(runner.nb)
    print "Returning."
    return output

if __name__ == "__main__":
    flask_app.run()



#!/usr/bin/env python
"""
Command Line Interface.
"""

import nbserve
import argparse

def main():
    parser = argparse.ArgumentParser(
        prog=nbserve.__progname__,
        description=nbserve.__description__,
        version='%s %s' % (nbserve.__progname__, nbserve.__version__))

    parser.add_argument("working_directory", nargs='?', default=".", type=str)
    parser.add_argument("-p", dest="port", action="store", default=None, type=int)
    parser.add_argument("--no-debug", dest="debug", action="store_false", default=True)

    args = parser.parse_args()


    nbserve.set_working_directory(args.working_directory)

    print "Running. For usage info and options, type %s -h." % nbserve.__progname__
    print "Press Ctrl-C or similar to stop."

    nbserve.flask_app.run(debug=args.debug, port=args.port)

if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

# Get  __version__
exec(open('nbserve/meta.py').read())

requires = ['flask',
            'runipy',
            'ipython',
            'tornado',
            'jinja2',
            'pyzmq']
setup(
    name=__progname__,
    version=__version__,
    long_description=__description__,
    author=__author__,
    author_email=__author_email__,
    url=__url__,
    keywords=__keywords__,
    packages=find_packages(exclude=['tests*']),
    include_package_data=True,
    zip_safe=False,
    install_requires=requires,
    entry_points = {
        'console_scripts': ['nbserve=nbserve.cli:main']
        }
)



__progname__ = "nbserve"
__version__ = '0.1.0'
__description__ = """nbserve is a simple script that lets you serve
iPython notebooks as read-only HTML files over the web. It has some
default options that make the notebooks appropriate for generating
reports, such as hiding input cells."""
__author__ = 'Rob Chambers'
__author_email__ = 'rdchambers@gmail.com'
__url__ = 'https://github.com/robchambers/nbserve'
__keywords__ = ['iPython', 'notebook', 'flask', 'server']